from setuptools import find_packages, setup

setup(
    name="doeloe",
    version="0.0.1",
    description="A tool to convert old Indonesian language into EYD (Ejaan yang Disempurnakan)",
    author="David Samuel",
    author_email="davidsamuel.7878@gmail.com",
    url="https://github.com/bookbot-hive/doeloe",
    license="Apache License",
    packages=find_packages(),
    include_package_data=True,
    platforms=["linux", "unix", "windows"],
)



import re


def transliterate(text):
    mapping = {
        "dj": "j",
        "j": "y",
        "tj": "c",
        "oe": "u",
        "nj": "ny",
        "sj": "sy",
        "ch": "kh",
    }

    for k in list(mapping.keys()):
        mapping[k.capitalize()] = mapping[k].capitalize()

    pattern = re.compile("|".join(re.escape(key) for key in mapping.keys()))
    output_string = pattern.sub(lambda x: mapping[x.group()], text)

    return output_string
